@@ -1,4 +1,4 @@
-/*  kftgtd.c,v 1.7 2005/05/20 01:17:28 eagle Exp
+/*  $Id: kftgtd.c 2300 2005-12-22 00:29:26Z rra $
 **
 **  Server program for Kerberos v4 ticket forwarding.
 */
@@ -75,6 +75,9 @@ main(argc,argv)
 
   prog = argv[0];
 
+#ifdef HAVE_DECL_KRB_IGNORE_IP_ADDRESS
+  krb_ignore_ip_address = 1;
+#endif
  
   while ((c = getopt(argc, argv, "hlvdt:")) != EOF) 
      switch (c) {
@@ -90,8 +93,7 @@ main(argc,argv)
   if (t_val <0) usage();
 
   if (v_flag) {
-    fprintf(stderr,"%s version %d.%d\n", prog, 
-                        KFTGT_MAJOR_VERSION, KFTGT_MINOR_VERSION);
+    fprintf(stderr,"%s version %s\n", prog, PACKAGE_VERSION);
     exit(0);
   }
 
