@@ -1,4 +1,4 @@
-/*  marsh.c,v 1.3 2005/05/20 01:17:28 eagle Exp
+/*  $Id: marsh.c 2293 2005-12-03 19:51:13Z rra $
 **
 **  Routines to marshall/unmarshall parameters and ticket-granting tickets.
 */
@@ -91,12 +91,12 @@ typedef unsigned short my_u_short;
 
 */
   
-#define PUT_COUNTED_STRING(string,dest) { \
-    KRB_UINT32 temp; \
-    temp = strlen(string); \
-    PUTLONG(temp,dest); \
-    strncpy(dest,string,temp); \
-    dest+= temp; \
+#define PUT_COUNTED_STRING(string,dest) {       \
+    KRB_UINT32 temp;                            \
+    temp = strlen(string);                      \
+    PUTLONG(temp,dest);                         \
+    strncpy(dest,string,temp);                  \
+    dest+= temp;                                \
   }
 
 /* put arbitrary data */
@@ -122,15 +122,15 @@ typedef unsigned short my_u_short;
 
 /* get a counted string, checking for space in source and dest */
 
-#define GET_COUNTED_STRING(dest,src,dest_max, cur_len,max_len) { \
-  KRB_UINT32 count; \
-  GET_LONG(count, src, cur_len, max_len); \
-  CHECK_LENGTH(count, dest_max); \
-  CHECK_LENGTH(cur_len+count, max_len); \
-  strncpy(dest,p,count); \
-  dest[count] = '\0'; \
-  cur_len += count; \
-  src += count; \
+#define GET_COUNTED_STRING(dest,src,dest_max, cur_len,max_len) {        \
+    KRB_UINT32 count;                                                   \
+    GET_LONG(count, src, cur_len, max_len);                             \
+    CHECK_LENGTH(count, dest_max);                                      \
+    CHECK_LENGTH(cur_len+count, max_len);                               \
+    strncpy(dest,(char *) p,count);                                     \
+    dest[count] = '\0';                                                 \
+    cur_len += count;                                                   \
+    src += count;                                                       \
   }
 
 
@@ -183,11 +183,11 @@ marshall_cred (
 int 
 unmarshall_cred(
        CREDENTIALS *cred,
-       char *buffer,
+       unsigned char *buffer,
        int max_len)
 {
 
-  char *p;
+  unsigned char *p;
   int len;
   KRB_UINT32 temp, version;
 
@@ -245,10 +245,10 @@ int unmarshall_params(
       int max_user,
       char *ticketfile,
       int max_ticket,
-      char *buffer,
+      unsigned char *buffer,
       int  max_len)
 {
-    char *p;
+    unsigned char *p;
     int len;
  
     p = buffer;
@@ -257,4 +257,3 @@ int unmarshall_params(
     GET_COUNTED_STRING(ticketfile, p, max_ticket, len, max_len);
     return len;
 }
-
