@@ -3,9 +3,9 @@
  *
  * marsh.h -   protos for marsh.c
  *
- * marsh.h,v 1.1 1994/06/08 17:28:46 schemers Exp
+ * $Id: marsh.h 2293 2005-12-03 19:51:13Z rra $
  *
- * marsh.h,v
+ * $Log$
  * Revision 1.1  1994/06/08 17:28:46  schemers
  * Initial revision
  *
@@ -26,7 +26,7 @@ marshall_cred(
 int 
 unmarshall_cred(
        CREDENTIALS *cred,
-       char *buffer,
+       unsigned char *buffer,
        int len);
 
 int marshall_params(
@@ -40,7 +40,7 @@ int unmarshall_params(
       int max_user,
       char *ticketfile,
       int max_ticket,
-      char *buffer,
+      unsigned char *buffer,
       int  max_len);
 
 #endif
